RDFCalendar.Parsers.DuplicateResourceError

Package RDFCalendar :: Module Parsers :: Class DuplicateResourceError |
[show private | hide private]
[frames | no frames]

## Class DuplicateResourceError

    Exception --+
                |
               DuplicateResourceError

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net